<?php

/**
* Main block class for graph_stats block
* @package block-graphs_stats
* @category blocks
* @author Eric Bugnet
*/


class block_graph_stats extends block_base {
	
	/**
	* Standard block API function for initializing block instance
	* @return void
	*/
	function init() {
		$this->title = get_string('blockname', 'block_graph_stats');
		$this->version = 2008062000;
	}
	
	/**
	* Standard block API function for telling block has configuration
	* @return boolean
	*/
	function has_config() {
		return true;
	}	

	/**
	* Standard block API function for printing block content
	* @uses $CFG
	* @uses $COURSE
	* @uses $USER
	*/
	function get_content() {
		global $CFG,$COURSE,$USER;
		
		if (	(!isset($CFG->block_graph_stats_daysnb)) ||
			(!isset($CFG->block_graph_stats_graphwidth)) ||
			(!isset($CFG->block_graph_stats_graphheight)) ||
			(!isset($CFG->block_graph_stats_outer_background)) ||
			(!isset($CFG->block_graph_stats_inner_background)) ||
			(!isset($CFG->block_graph_stats_inner_border)) ||
			(!isset($CFG->block_graph_stats_axis_colour)) ||
			(!isset($CFG->block_graph_stats_color1)) ||
			(!isset($CFG->block_graph_stats_color2)) ||
			(!isset($CFG->block_graph_stats_multi))){
		    $this->content->text = '<span class="errorcode">'.get_string('seemsnotconfigured', 'block_graph_stats').'</span>';
		    $this->content->footer = ''; 
		    return $this->content;
		}
		
		$daysnb = $CFG->block_graph_stats_daysnb;

		if ($this->content !== NULL) {
			return $this->content;
		}
		

		$this->content = new stdClass;
		
		// Make a link to details if user can edit the site
		$context=get_context_instance(CONTEXT_COURSE, $COURSE->id);
		if (($COURSE->id==1) AND (has_capability('moodle/site:config', $context))) {
			$name = 'popup';
			$title = get_string('connectedtoday','block_graph_stats');
			$url = '/blocks/graph_stats/details.php';
			$options = 'menubar=0,location=0,scrollbars,resizable,width=400,height=500';
			$fullscreen = 0;
			$linkname =  '<img src="'.$CFG->wwwroot.'/blocks/graph_stats/graph.php?course_id='.$COURSE->id.'" alt="'.get_string('graphtitle','block_graph_stats', $daysnb).'" />';
			$this->content->text .= '<center><a target="'. $name .'" title="'. $title .'" href="'. $CFG->wwwroot . $url .'" '. "onclick=\"return openpopup('$url', '$name', '$options', $fullscreen);\">$linkname</a></center>";
		} else {
			$this->content->text .= '<center><img src="'.$CFG->wwwroot.'/blocks/graph_stats/graph.php?course_id='.$COURSE->id.'" title="'.get_string('graphtitle','block_graph_stats', $daysnb).'" /></center>';
		}
		
					
		if ($COURSE->id>1) { 
			// In a course
			$connections = count_records_select('log', 'time > '.mktime(0, 0, 0, date("m") , date("d"), date("Y")).' AND action = "view" AND course = '.$COURSE->id.' ', 'COUNT(DISTINCT(userid))');
			$this->content->text .= get_string('connectedtoday','block_graph_stats').$connections;
		} else {
			// On the first page
			// Graph
			$connections = count_records_select('log', 'time > '.mktime(0, 0, 0, date("m") , date("d"), date("Y")).' AND action = "login"', 'COUNT(userid)');
			$this->content->text .= get_string('connectedtoday','block_graph_stats').$connections;
			// Details
			$users = count_records('user','deleted',0,'confirmed',1);
			$courses = count_records('course','visible',1);
			$this->content->text .= '<hr />';
			$this->content->text .= get_string('membersnb','block_graph_stats').$users. '<br />';
			$this->content->text .= get_string('coursesnb','block_graph_stats').$courses.'<br />';
		}
		
			$this->content->footer = '';

		return $this->content;
	}
}
?>
